@@ -18,6 +18,7 @@ from lux.vis.Clause import Clause
 from lux.vis.Vis import Vis
 from lux.vis.VisList import VisList
 from lux.history.history import History
+from lux.utils.date_utils import is_datetime_series
 from lux.utils.message import Message
 from lux.utils.utils import check_import_lux_widget
 from typing import Dict, Union, List, Callable
@@ -37,7 +38,7 @@ class LuxDataFrame(pd.DataFrame):
     _metadata = [
         "_intent",
         "_inferred_intent",
-        "data_type",
+        "_data_type",
         "unique_values",
         "cardinality",
         "_rec_info",
@@ -53,11 +54,10 @@ class LuxDataFrame(pd.DataFrame):
         "_message",
         "_pandas_only",
         "pre_aggregated",
+        "_type_override",
     ]
 
     def __init__(self, *args, **kw):
-        from lux.executor.PandasExecutor import PandasExecutor
-
         self._history = History()
         self._intent = []
         self._inferred_intent = []
@@ -69,18 +69,26 @@ class LuxDataFrame(pd.DataFrame):
         super(LuxDataFrame, self).__init__(*args, **kw)
 
         self.table_name = ""
-        lux.config.executor = PandasExecutor()
+        if lux.config.SQLconnection == "":
+            from lux.executor.PandasExecutor import PandasExecutor
+
+            lux.config.executor = PandasExecutor()
+        else:
+            from lux.executor.SQLExecutor import SQLExecutor
+
+            lux.config.executor = SQLExecutor()
 
         self._sampled = None
         self._toggle_pandas_display = True
         self._message = Message()
         self._pandas_only = False
         # Metadata
-        self.data_type = None
+        self._data_type = {}
         self.unique_values = None
         self.cardinality = None
         self._min_max = None
         self.pre_aggregated = None
+        self._type_override = {}
         warnings.formatwarning = lux.warning_format
 
     @property
@@ -101,15 +109,32 @@ class LuxDataFrame(pd.DataFrame):
     def history(self):
         return self._history
 
+    @property
+    def data_type(self):
+        if not self._data_type:
+            self.maintain_metadata()
+        return self._data_type
+
     def maintain_metadata(self):
+        is_sql_tbl = lux.config.executor.name == "SQLExecutor"
+        if lux.config.SQLconnection != "" and is_sql_tbl:
+            from lux.executor.SQLExecutor import SQLExecutor
+
+            lux.config.executor = SQLExecutor()
+
         # Check that metadata has not yet been computed
         if not hasattr(self, "_metadata_fresh") or not self._metadata_fresh:
             # only compute metadata information if the dataframe is non-empty
-            if len(self) > 0:
-                lux.config.executor.compute_stats(self)
+            if is_sql_tbl:
                 lux.config.executor.compute_dataset_metadata(self)
                 self._infer_structure()
                 self._metadata_fresh = True
+            else:
+                if len(self) > 0:
+                    lux.config.executor.compute_stats(self)
+                    lux.config.executor.compute_dataset_metadata(self)
+                    self._infer_structure()
+                    self._metadata_fresh = True
 
     def expire_recs(self):
         """
@@ -117,7 +142,6 @@ class LuxDataFrame(pd.DataFrame):
         """
         self._recs_fresh = False
         self._recommendation = {}
-        self.current_vis = None
         self._widget = None
         self._rec_info = None
         self._sampled = None
@@ -127,7 +151,7 @@ class LuxDataFrame(pd.DataFrame):
         Expire all saved metadata to trigger a recomputation the next time the data is required.
         """
         self._metadata_fresh = False
-        self.data_type = None
+        self._data_type = None
         self.unique_values = None
         self.cardinality = None
         self._min_max = None
@@ -161,13 +185,14 @@ class LuxDataFrame(pd.DataFrame):
         # If the dataframe is very small and the index column is not a range index, then it is likely that this is an aggregated data
         is_multi_index_flag = self.index.nlevels != 1
         not_int_index_flag = not pd.api.types.is_integer_dtype(self.index)
-        small_df_flag = len(self) < 100
-        self.pre_aggregated = (is_multi_index_flag or not_int_index_flag) and small_df_flag
-        if "Number of Records" in self.columns:
-            self.pre_aggregated = True
-        very_small_df_flag = len(self) <= 10
-        if very_small_df_flag:
-            self.pre_aggregated = True
+        is_sql_tbl = lux.config.executor.name == "SQLExecutor"
+
+        small_df_flag = len(self) < 100 and is_sql_tbl
+        if self.pre_aggregated == None:
+            self.pre_aggregated = (is_multi_index_flag or not_int_index_flag) and small_df_flag
+            if "Number of Records" in self.columns:
+                self.pre_aggregated = True
+            self.pre_aggregated = "groupby" in [event.name for event in self.history] and not is_sql_tbl
 
     @property
     def intent(self):
@@ -242,6 +267,40 @@ class LuxDataFrame(pd.DataFrame):
         self._intent = vis._inferred_intent
         self._parse_validate_compile_intent()
 
+    def set_data_type(self, types: dict):
+        """
+        Set the data type for a particular attribute in the dataframe
+        overriding the automatically-detected type inferred by Lux
+
+        Parameters
+        ----------
+        types: dict
+            Dictionary that maps attribute/column name to a specified Lux Type.
+            Possible options: "nominal", "quantitative", "id", and "temporal".
+
+        Example
+        ----------
+        df = pd.read_csv("https://raw.githubusercontent.com/lux-org/lux-datasets/master/data/absenteeism.csv")
+        df.set_data_type({"ID":"id",
+                          "Reason for absence":"nominal"})
+        """
+        if self._type_override == None:
+            self._type_override = types
+        else:
+            self._type_override = {**self._type_override, **types}
+
+        if not self.data_type:
+            self.maintain_metadata()
+
+        for attr in types:
+            if types[attr] not in ["nominal", "quantitative", "id", "temporal"]:
+                raise ValueError(
+                    f'Invalid data type option specified for {attr}. Please use one of the following supported types: ["nominal", "quantitative", "id", "temporal"]'
+                )
+            self.data_type[attr] = types[attr]
+
+        self.expire_recs()
+
     def to_pandas(self):
         import lux.core
 
@@ -263,13 +322,17 @@ class LuxDataFrame(pd.DataFrame):
 
     @property
     def current_vis(self):
+        from lux.processor.Validator import Validator
+
         # _parse_validate_compile_intent does not call executor,
         # we only attach data to current vis when user request current_vis
-        if (
+        valid_current_vis = (
             self._current_vis is not None
             and len(self._current_vis) > 0
             and self._current_vis[0].data is None
-        ):
+            and self._current_vis[0].intent
+        )
+        if valid_current_vis and Validator.validate_intent(self._current_vis[0].intent, self):
             lux.config.executor.execute(self._current_vis, self)
         return self._current_vis
 
@@ -277,117 +340,18 @@ class LuxDataFrame(pd.DataFrame):
     def current_vis(self, current_vis: Dict):
         self._current_vis = current_vis
 
-    def __repr__(self):
-        # TODO: _repr_ gets called from _repr_html, need to get rid of this call
-        return ""
-
-    #######################################################
-    ########## SQL Metadata, type, model schema ###########
-    #######################################################
-
-    def set_SQL_table(self, t_name):
-        self.table_name = t_name
-        self.compute_SQL_dataset_metadata()
-
-    def compute_SQL_dataset_metadata(self):
-        self.get_SQL_attributes()
-        for attr in list(self.columns):
-            self[attr] = None
-        self.data_type = {}
-        #####NOTE: since we aren't expecting users to do much data processing with the SQL database, should we just keep this
-        #####      in the initialization and do it just once
-        self.compute_SQL_data_type()
-        self.compute_SQL_stats()
-
-    def compute_SQL_stats(self):
-        # precompute statistics
-        self.unique_values = {}
-        self._min_max = {}
-
-        self.get_SQL_unique_values()
-        # self.get_SQL_cardinality()
-        for attribute in self.columns:
-            if self.data_type[attribute] == "quantitative":
-                self._min_max[attribute] = (
-                    self[attribute].min(),
-                    self[attribute].max(),
-                )
-
-    def get_SQL_attributes(self):
-        if "." in self.table_name:
-            table_name = self.table_name[self.table_name.index(".") + 1 :]
-        else:
-            table_name = self.table_name
-        query = f"SELECT column_name FROM INFORMATION_SCHEMA.COLUMNS where TABLE_NAME = '{table_name}'"
-        attributes = list(pd.read_sql(query, lux.config.SQLconnection)["column_name"])
-        for attr in attributes:
-            self[attr] = None
-
-    def get_SQL_cardinality(self):
-        cardinality = {}
-        for attr in list(self.columns):
-            card_query = pd.read_sql(
-                f"SELECT Count(Distinct({attr})) FROM {self.table_name}",
-                lux.config.SQLconnection,
-            )
-            cardinality[attr] = list(card_query["count"])[0]
-        self.cardinality = cardinality
-
-    def get_SQL_unique_values(self):
-        unique_vals = {}
-        for attr in list(self.columns):
-            unique_query = pd.read_sql(
-                f"SELECT Distinct({attr}) FROM {self.table_name}",
-                lux.config.SQLconnection,
-            )
-            unique_vals[attr] = list(unique_query[attr])
-        self.unique_values = unique_vals
-
-    def compute_SQL_data_type(self):
-        data_type = {}
-        sql_dtypes = {}
-        self.get_SQL_cardinality()
-        if "." in self.table_name:
-            table_name = self.table_name[self.table_name.index(".") + 1 :]
-        else:
-            table_name = self.table_name
-        # get the data types of the attributes in the SQL table
-        for attr in list(self.columns):
-            query = f"SELECT DATA_TYPE FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = '{table_name}' AND COLUMN_NAME = '{attr}'"
-            datatype = list(pd.read_sql(query, lux.config.SQLconnection)["data_type"])[0]
-            sql_dtypes[attr] = datatype
-
-        for attr in list(self.columns):
-            if str(attr).lower() in ["month", "year"]:
-                data_type[attr] = "temporal"
-            elif sql_dtypes[attr] in [
-                "character",
-                "character varying",
-                "boolean",
-                "uuid",
-                "text",
-            ]:
-                data_type[attr] = "nominal"
-            elif sql_dtypes[attr] in [
-                "integer",
-                "real",
-                "smallint",
-                "smallserial",
-                "serial",
-            ]:
-                if self.cardinality[attr] < 13:
-                    data_type[attr] = "nominal"
-                else:
-                    data_type[attr] = "quantitative"
-            elif "time" in sql_dtypes[attr] or "date" in sql_dtypes[attr]:
-                data_type[attr] = "temporal"
-        self.data_type = data_type
-
     def _append_rec(self, rec_infolist, recommendations: Dict):
         if recommendations["collection"] is not None and len(recommendations["collection"]) > 0:
             rec_infolist.append(recommendations)
 
-    def maintain_recs(self):
+    def show_all_column_vis(self):
+        if self.intent == [] or self.intent is None:
+            vis = Vis(list(self.columns), self)
+            if vis.mark != "":
+                vis._all_column = True
+                self.current_vis = VisList([vis])
+
+    def maintain_recs(self, is_series="DataFrame"):
         # `rec_df` is the dataframe to generate the recommendations on
         # check to see if globally defined actions have been registered/removed
         if lux.config.update_actions["flag"] == True:
@@ -406,17 +370,33 @@ class LuxDataFrame(pd.DataFrame):
             rec_df = self
             rec_df._message = Message()
         # Add warning message if there exist ID fields
-        id_fields_str = ""
-        inverted_data_type = lux.config.executor.invert_data_type(rec_df.data_type)
-        if len(inverted_data_type["id"]) > 0:
-            for id_field in inverted_data_type["id"]:
-                id_fields_str += f"<code>{id_field}</code>, "
-            id_fields_str = id_fields_str[:-2]
-            rec_df._message.add(f"{id_fields_str} is not visualized since it resembles an ID field.")
+        if len(rec_df) == 0:
+            rec_df._message.add(f"Lux cannot operate on an empty {is_series}.")
+        elif len(rec_df) < 5 and not rec_df.pre_aggregated:
+            rec_df._message.add(
+                f"The {is_series} is too small to visualize. To generate visualizations in Lux, the {is_series} must contain at least 5 rows."
+            )
+        elif self.index.nlevels >= 2 or self.columns.nlevels >= 2:
+            rec_df._message.add(
+                f"Lux does not currently support visualizations in a {is_series} "
+                f"with hierarchical indexes.\n"
+                f"Please convert the {is_series} into a flat "
+                f"table via pandas.DataFrame.reset_index."
+            )
+        else:
+            id_fields_str = ""
+            inverted_data_type = lux.config.executor.invert_data_type(rec_df.data_type)
+            if len(inverted_data_type["id"]) > 0:
+                for id_field in inverted_data_type["id"]:
+                    id_fields_str += f"<code>{id_field}</code>, "
+                id_fields_str = id_fields_str[:-2]
+                rec_df._message.add(f"{id_fields_str} is not visualized since it resembles an ID field.")
+
         rec_df._prev = None  # reset _prev
 
         # Check that recs has not yet been computed
         if not hasattr(rec_df, "_recs_fresh") or not rec_df._recs_fresh:
+            is_sql_tbl = lux.config.executor.name == "SQLExecutor"
             rec_infolist = []
             from lux.action.row_group import row_group
             from lux.action.column_group import column_group
@@ -426,8 +406,9 @@ class LuxDataFrame(pd.DataFrame):
                 if rec_df.columns.name is not None:
                     rec_df._append_rec(rec_infolist, row_group(rec_df))
                 rec_df._append_rec(rec_infolist, column_group(rec_df))
-            else:
-                # if rec_df._recommendation == {}:
+            elif not (len(rec_df) < 5 and not rec_df.pre_aggregated and not is_sql_tbl) and not (
+                self.index.nlevels >= 2 or self.columns.nlevels >= 2
+            ):
                 from lux.action.custom import custom_actions
 
                 # generate vis from globally registered actions and append to dataframe
@@ -444,9 +425,11 @@ class LuxDataFrame(pd.DataFrame):
                 if len(vlist) > 0:
                     rec_df._recommendation[action_type] = vlist
             rec_df._rec_info = rec_infolist
+            rec_df.show_all_column_vis()
             self._widget = rec_df.render_widget()
         # re-render widget for the current dataframe if previous rec is not recomputed
         elif show_prev:
+            rec_df.show_all_column_vis()
             self._widget = rec_df.render_widget()
         self._recs_fresh = True
 
@@ -561,7 +544,7 @@ class LuxDataFrame(pd.DataFrame):
         self._widget.observe(self.remove_deleted_recs, names="deletedIndices")
         self._widget.observe(self.set_intent_on_click, names="selectedIntentIndex")
 
-    def _repr_html_(self):
+    def _ipython_display_(self):
         from IPython.display import display
         from IPython.display import clear_output
         import ipywidgets as widgets
@@ -571,30 +554,13 @@ class LuxDataFrame(pd.DataFrame):
                 display(self.display_pandas())
                 self._pandas_only = False
             else:
-                if self.index.nlevels >= 2 or self.columns.nlevels >= 2:
-                    warnings.warn(
-                        "\nLux does not currently support dataframes "
-                        "with hierarchical indexes.\n"
-                        "Please convert the dataframe into a flat "
-                        "table via `pandas.DataFrame.reset_index`.\n",
-                        stacklevel=2,
-                    )
-                    display(self.display_pandas())
-                    return
+                if not self.index.nlevels >= 2 or self.columns.nlevels >= 2:
+                    self.maintain_metadata()
 
-                if len(self) <= 0:
-                    warnings.warn(
-                        "\nLux can not operate on an empty dataframe.\nPlease check your input again.\n",
-                        stacklevel=2,
-                    )
-                    display(self.display_pandas())
-                    return
-                self.maintain_metadata()
+                    if self._intent != [] and (not hasattr(self, "_compiled") or not self._compiled):
+                        from lux.processor.Compiler import Compiler
 
-                if self._intent != [] and (not hasattr(self, "_compiled") or not self._compiled):
-                    from lux.processor.Compiler import Compiler
-
-                    self.current_vis = Compiler.compile_intent(self, self._intent)
+                        self.current_vis = Compiler.compile_intent(self, self._intent)
 
                 if lux.config.default_display == "lux":
                     self._toggle_pandas_display = False
@@ -608,50 +574,42 @@ class LuxDataFrame(pd.DataFrame):
                 self._widget.observe(self.remove_deleted_recs, names="deletedIndices")
                 self._widget.observe(self.set_intent_on_click, names="selectedIntentIndex")
 
-                if len(self._recommendation) > 0:
-                    # box = widgets.Box(layout=widgets.Layout(display='inline'))
-                    button = widgets.Button(
-                        description="Toggle Pandas/Lux",
-                        layout=widgets.Layout(width="140px", top="5px"),
-                    )
-                    self.output = widgets.Output()
-                    # box.children = [button,output]
-                    # output.children = [button]
-                    # display(box)
-                    display(button, self.output)
+                button = widgets.Button(
+                    description="Toggle Pandas/Lux",
+                    layout=widgets.Layout(width="140px", top="5px"),
+                )
+                self.output = widgets.Output()
+                display(button, self.output)
 
-                    def on_button_clicked(b):
-                        with self.output:
-                            if b:
-                                self._toggle_pandas_display = not self._toggle_pandas_display
-                            clear_output()
-                            if self._toggle_pandas_display:
-                                display(self.display_pandas())
-                            else:
-                                # b.layout.display = "none"
-                                display(self._widget)
-                                # b.layout.display = "inline-block"
+                def on_button_clicked(b):
+                    with self.output:
+                        if b:
+                            self._toggle_pandas_display = not self._toggle_pandas_display
+                        clear_output()
+                        if self._toggle_pandas_display:
+                            display(self.display_pandas())
+                        else:
+                            # b.layout.display = "none"
+                            display(self._widget)
+                            # b.layout.display = "inline-block"
 
-                    button.on_click(on_button_clicked)
-                    on_button_clicked(None)
-                else:
-                    warnings.warn(
-                        "\nLux defaults to Pandas when there are no valid actions defined.",
-                        stacklevel=2,
-                    )
-                    display(self.display_pandas())
+                button.on_click(on_button_clicked)
+                on_button_clicked(None)
 
         except (KeyboardInterrupt, SystemExit):
             raise
         except Exception:
-            warnings.warn(
-                "\nUnexpected error in rendering Lux widget and recommendations. "
-                "Falling back to Pandas display.\n"
-                "Please report the following issue on Github: https://github.com/lux-org/lux/issues \n",
-                stacklevel=2,
-            )
-            warnings.warn(traceback.format_exc())
-            display(self.display_pandas())
+            if lux.config.pandas_fallback:
+                warnings.warn(
+                    "\nUnexpected error in rendering Lux widget and recommendations. "
+                    "Falling back to Pandas display.\n"
+                    "Please report the following issue on Github: https://github.com/lux-org/lux/issues \n",
+                    stacklevel=2,
+                )
+                warnings.warn(traceback.format_exc())
+                display(self.display_pandas())
+            else:
+                raise
 
     def display_pandas(self):
         return self.to_pandas()
@@ -745,9 +703,13 @@ class LuxDataFrame(pd.DataFrame):
         current_vis_spec = {}
         numVC = len(vlist)  # number of visualizations in the vis list
         if numVC == 1:
-            current_vis_spec = vlist[0].to_code(prettyOutput=False)
+            current_vis_spec = vlist[0].to_code(language=lux.config.plotting_backend, prettyOutput=False)
         elif numVC > 1:
             pass
+        if vlist[0]._all_column:
+            current_vis_spec["allcols"] = True
+        else:
+            current_vis_spec["allcols"] = False
         return current_vis_spec
 
     @staticmethod
@@ -760,7 +722,7 @@ class LuxDataFrame(pd.DataFrame):
             if len(rec["collection"]) > 0:
                 rec["vspec"] = []
                 for vis in rec["collection"]:
-                    chart = vis.to_code(prettyOutput=False)
+                    chart = vis.to_code(language=lux.config.plotting_backend, prettyOutput=False)
                     rec["vspec"].append(chart)
                 rec_lst.append(rec)
                 # delete since not JSON serializable
@@ -855,21 +817,34 @@ class LuxDataFrame(pd.DataFrame):
 
     # Overridden Pandas Functions
     def head(self, n: int = 5):
-        self._prev = self
-        self._history.append_event("head", n=5)
-        return super(LuxDataFrame, self).head(n)
+        ret_val = super(LuxDataFrame, self).head(n)
+        ret_val._prev = self
+        ret_val._history.append_event("head", n=5)
+        return ret_val
 
     def tail(self, n: int = 5):
-        self._prev = self
-        self._history.append_event("tail", n=5)
-        return super(LuxDataFrame, self).tail(n)
-
-    def info(self, *args, **kwargs):
-        self._pandas_only = True
-        self._history.append_event("info", *args, **kwargs)
-        return super(LuxDataFrame, self).info(*args, **kwargs)
+        ret_val = super(LuxDataFrame, self).tail(n)
+        ret_val._prev = self
+        ret_val._history.append_event("tail", n=5)
+        return ret_val
 
     def describe(self, *args, **kwargs):
-        self._pandas_only = True
-        self._history.append_event("describe", *args, **kwargs)
-        return super(LuxDataFrame, self).describe(*args, **kwargs)
+        ret_val = super(LuxDataFrame, self).describe(*args, **kwargs)
+        ret_val._pandas_only = True
+        ret_val._history.append_event("describe", *args, **kwargs)
+        return ret_val
+
+    def groupby(self, *args, **kwargs):
+        history_flag = False
+        if "history" not in kwargs or ("history" in kwargs and kwargs["history"]):
+            history_flag = True
+        if "history" in kwargs:
+            del kwargs["history"]
+        groupby_obj = super(LuxDataFrame, self).groupby(*args, **kwargs)
+        for attr in self._metadata:
+            groupby_obj.__dict__[attr] = getattr(self, attr, None)
+        if history_flag:
+            groupby_obj._history = groupby_obj._history.copy()
+            groupby_obj._history.append_event("groupby", *args, **kwargs)
+        groupby_obj.pre_aggregated = True
+        return groupby_obj
