@@ -57,7 +57,7 @@ class Executor:
 
     def mapping(self, rmap):
         group_map = {}
-        for val in ["quantitative", "id", "nominal", "temporal", "geoshape"]:
+        for val in ["quantitative", "id", "nominal", "temporal", "geographical"]:
             group_map[val] = list(filter(lambda x: rmap[x] == val, rmap))
         return group_map
 
@@ -74,10 +74,11 @@ class Executor:
     def compute_data_model(self, data_type):
         data_type_inverted = self.invert_data_type(data_type)
         data_model = {
-            "measure": data_type_inverted["quantitative"] + data_type_inverted["geoshape"],
+            "measure": data_type_inverted["quantitative"],
             "dimension": data_type_inverted["nominal"]
             + data_type_inverted["temporal"]
-            + data_type_inverted["id"],
+            + data_type_inverted["id"]
+            + data_type_inverted["geographical"],
         }
         return data_model
 
